// Class: BMICalculator (person, height, weight, activity)
// Kyoung Shin Park (Java Programming I)
public class BMICalculator extends Person {
	protected double height;
	protected double weight;
	protected Activity activity;

	public BMICalculator() {
		this("J", 20, Gender.FEMALE, 165.0, 55.0, Activity.MEDIUM);
	}

    public BMICalculator(String name, int age, Gender gender, double height, double weight, Activity activity) {
		super(name, age, gender);
		this.height = height;
		this.weight = weight;
        this.activity = activity;
    }

	public void setHeight(double height) {
		this.height = height;	
	}
    
	public void setWeight(double weight) {
		this.weight = weight;
	}

	public void setActivity(Activity activity) {
		this.activity = activity;
	}

	public double getHeight() {
		return height;
	}

	public double getWeight() {
		return weight;
	}

    public Activity getActivity() { 
		return activity; 
	}

    @Override 
	public String toString() { 
		return "BMICalculator Name=" + name + " Age=" + age + " Gender=" + gender + " Height=" + height + " Weight=" + weight + " BMI=" + calculateBMI(); 
	}
	
	public BMI calculateBMI() {
        double bmi = weight / (height * 0.01) / (height * 0.01);
        if (bmi >= 0.0 && bmi < 20.0) 
			return BMI.UNDERWEIGHT;
		else if (bmi >= 20.0 && bmi < 24.0) 
			return BMI.NORMAL;
		else if (bmi >= 24.0 && bmi < 30.0) 
			return BMI.OVERWEIGHT;
		else 
			return BMI.OBESITY;		
    }

    public double calculateStandardWeight()	{
		if (this.gender == Gender.MALE)
			return height * height * 22 * 0.0001;
		else
			return height * height * 21 * 0.0001;
	}
    
	// Herris Benedict Equation
    public double calculateDailyCaloryIntake() {
        double activityCalory = 1.0;
        switch (this.activity) {
        case LOW:
            activityCalory = 1.3;
			break;
        case MEDIUM:
            activityCalory = 1.5;
			break;
        case HIGH:
            activityCalory = 1.75;
			break;
		default:
			break;
        }

        if (this.gender == Gender.MALE)
            return 66.47 + (13.75 * this.weight) + (5.0 * this.height) - (6.76 * (double)(this.age)) * activityCalory;
		else
			return 655.1 + (9.05 * this.weight) + (1.85 * this.height) - (4.68 * (double)(this.age)) * activityCalory;
    }
}